diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/__init__.py
index 1fb6d3c..48c9ef6 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/__init__.py
@@ -157,6 +157,9 @@ class ForeignTableView(PGChildNodeView, DataTypeReader):
 
     * dependencies(gid, sid, did, scid, foid):
       - Returns the dependencies for the Foreign Table object.
+
+    * select_sql(gid, sid, did, scid, foid):
+      - Returns sql for Script
     """
 
     node_type = blueprint.node_type
@@ -193,7 +196,8 @@ class ForeignTableView(PGChildNodeView, DataTypeReader):
         'get_foreign_servers': [{'get': 'get_foreign_servers'},
                                 {'get': 'get_foreign_servers'}],
         'get_tables': [{'get': 'get_tables'}, {'get': 'get_tables'}],
-        'get_columns': [{'get': 'get_columns'}, {'get': 'get_columns'}]
+        'get_columns': [{'get': 'get_columns'}, {'get': 'get_columns'}],
+        'select_sql': [{'get': 'select_sql'}]
     })
 
     def validate_request(f):
@@ -1118,4 +1122,38 @@ AND relkind != 'c'))"""
 
         return {"ftoptions": variables_lst}
 
+
+    @check_precondition
+    def select_sql(self, gid, sid, did, scid, foid):
+        """
+        SELECT script sql for the object
+
+        Args:
+            gid: Server Group Id
+            sid: Server Id
+            did: Database Id
+            scid: Schema Id
+            foid: Foreign Table Id
+
+        Returns:
+            SELECT Script sql for the object
+        """
+        data = self._fetch_properties(gid, sid, did, scid, foid)
+
+        columns = []
+        for c in data['columns']:
+            columns.append(self.qtIdent(self.conn, c['attname']))
+
+        if len(columns) > 0:
+            columns = ", ".join(columns)
+        else:
+            columns = '*'
+
+        sql = "SELECT {0}\n\tFROM {1};".format(
+            columns,
+            self.qtIdent(self.conn, data['basensp'], data['name'])
+        )
+
+        return ajax_response(response=sql)
+
 ForeignTableView.register_node_view(blueprint)
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/templates/foreign_tables/js/foreign_tables.js b/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/templates/foreign_tables/js/foreign_tables.js
index e6ed9f6..4ff8cf0 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/templates/foreign_tables/js/foreign_tables.js
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/foreign_tables/templates/foreign_tables/js/foreign_tables.js
@@ -534,6 +534,7 @@ function($, _, S, pgAdmin, pgBrowser, alertify) {
       collection_type: 'coll-foreign-table',
       hasSQL: true,
       hasDepends: true,
+      hasScriptTypes: ['create', 'select'],
       parent_type: ['schema'],
       Init: function() {
         /* Avoid multiple registration of menus */
